@@ -3,5 +3,5 @@
 
 from tempor.cli import main
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
